nltk.tag package
================

Submodules
----------

.. toctree::
   :maxdepth: 4

   nltk.tag.api
   nltk.tag.brill
   nltk.tag.brill_trainer
   nltk.tag.crf
   nltk.tag.hmm
   nltk.tag.hunpos
   nltk.tag.mapping
   nltk.tag.perceptron
   nltk.tag.senna
   nltk.tag.sequential
   nltk.tag.stanford
   nltk.tag.tnt
   nltk.tag.util

Module contents
---------------

.. automodule:: nltk.tag
   :members:
   :undoc-members:
   :show-inheritance:
